@@ -66,7 +66,7 @@ class Bronze():
             logging.info("Fim do processo")
             msg = msg + "\nFim do processo. "
 
-        return sucesso, msg, self.asynchronous
+        return sucesso, msg
 
 
     def __break_file(self):
@@ -90,42 +90,56 @@ class Bronze():
         
         logging.info(f"Nome do arquivo {file_name}")  
         logging.info(f"Caminho do arquivo {path_input_enrichment_input}")
-        logging.info(f"Quantidade de lote(s) {len(df_data)}")
+
 
         self.__delele_file(path_input_enrichment_input)
 
-        count = 1
         threads = list()
+        if isinstance(df_data, pd.DataFrame):
 
-        for chunk in df_data:
-    
-            logging.info(f"Iniciando quebra do arquivo {self.path_file} do lote {count}")
+            file_input_enrichment_input = os.path.join(path_input_enrichment_input, file_name + "_1.csv")
 
-            if isinstance(chunk, pd.DataFrame):
-                _df_data = chunk
-            else:
-                _df_data = next(chunk)
-
-            file_input_enrichment_input = os.path.join(path_input_enrichment_input, file_name + "_"+str(count)+".csv")
+            logging.info(f"Iniciando quebra do arquivo {file_input_enrichment_input} único")
 
             t = threading.Thread(target=self.ioContainerData.download, 
-                        args=(_df_data,
-                            file_input_enrichment_input,
-                            self.ioContainerData.name_container_silver,
-                            self.sep_processado)
-                        )
+                            args=(df_data,
+                                file_input_enrichment_input,
+                                self.ioContainerData.name_container_silver,
+                                self.sep_processado)
+                            )
             t.start()
             threads.append(t)
 
-            del(_df_data)
-            logging.info(f"Fim da quebra do arquivo {self.path_file} do lote {count}")
-            count = count + 1
+            logging.info(f"Fim da quebra do arquivo {file_input_enrichment_input} único")
 
+        else:
+        
+            count = 1
+            for _df_data in df_data:
+                
+                file_input_enrichment_input = os.path.join(path_input_enrichment_input, file_name + "_"+str(count)+".csv")
+
+                logging.info(f"Iniciando quebra do arquivo {file_input_enrichment_input} do lote {count}")
+
+                t = threading.Thread(target=self.ioContainerData.download, 
+                            args=(_df_data,
+                                file_input_enrichment_input,
+                                self.ioContainerData.name_container_silver,
+                                self.sep_processado)
+                            )
+                t.start()
+                threads.append(t)
+
+                del(_df_data)
+                count = count + 1
+
+                logging.info(f"Fim da quebra do arquivo {file_input_enrichment_input} do lote {count}")
+                
 
         for thread in threads:
             thread.join()
 
-
+        logging.info(f"Fim da quebra do arquivo {file_name}")
 
     def __delele_file(self, dir):
         
