@@ -1,6 +1,6 @@
 
-from datetime import datetime
 import os
+from pathlib import Path
 import pandas as pd
 from io import StringIO
 from azure.storage.blob import BlobServiceClient, __version__
@@ -20,7 +20,7 @@ class IOContainerData():
         
         self.dir_backup = 'archived/'
         self.dir_failed = 'failed/'
-        self.dir_input_enrichment='input/'
+        self.dir_input_enrichment_input='input/'
 
         self.name_container_bronze = "bronze"
         self.name_container_silver = "silver"
@@ -60,39 +60,78 @@ class IOContainerData():
         return blob_client_instance.download_blob()
 
 
-    def download_blob(self, name_container, file_path):
-
-        stream_blob = self.get_file( name_container, file_path )
-
-        self.get_extension(file_path)
-
-        if ( self.extension == ".xlsx" or self.extension == ".xls"):
-            content = stream_blob.content_as_bytes()
-            return len(content), content
-        else:
-            content = stream_blob.content_as_text()
-            return len(content), StringIO( content )
+    #def download_blob(self, name_container, file_path):
 
+    #    stream_blob = self.get_file( name_container, file_path )
 
+    #    self.get_extension(file_path)
 
+    #    if ( self.extension == ".xlsx" or self.extension == ".xls"):
+    #        content = stream_blob.content_as_bytes()
+    #        return len(content), content
+    #    else:
+    #        content = stream_blob.content_as_text()
+    #        return len(content), StringIO( content )
+ 
+    
     def get_content_length(self, name_container, file_path) -> int:
 
         container_client = self.blob_service_client.get_container_client(name_container)
         blob_client_instance = container_client.get_blob_client(file_path)
 
         a = blob_client_instance.get_blob_properties()
+
         self.content_length = a.size
 
         return self.content_length
 
 
-    def upload_frame_to_blob(self, container, file_name_blob, df_data):
+    def upload_frame_to_blob(self, container, file_name_blob, df_data, format):
 
-        container_client = self.blob_service_client.get_blob_client(container, blob=file_name_blob)
+        path = os.path.dirname(file_name_blob)
 
-        container_client.upload_blob(data=df_data.to_csv(index=False), overwrite=True)
+        if format.upper() == 'CSV':
+            name_file = Path(file_name_blob).stem + ".csv"
+            container_client = self.blob_service_client.get_blob_client(container, 
+                                                                        blob=os.path.join(path, name_file))
+                                                                        
+            container_client.upload_blob(data=df_data.to_csv(index=False), 
+                                        overwrite=True)
+        elif format.upper() == 'PARQUET':
+            name_file = Path(file_name_blob).stem + ".parquet"
+            container_client = self.blob_service_client.get_blob_client(container,
+                                                                        blob=os.path.join(path, name_file))
+
+            container_client.upload_blob(data=df_data.to_parquet(index=False, engine='pyarrow'), 
+                                        overwrite=True)
+        else:
+            raise Exception(f"Formato de arquivo invalido {format} use csv ou parquet")  
 
 
+    def __is_dir(self, file_path):
+        return '.' not in os.path.basename(file_path)
+
+    def delete_to_blob(self, container_name, file_path):
+
+        if( self.__is_dir(file_path) ):
+
+            container_client = self.blob_service_client.get_container_client(container_name)
+            blob_list = container_client.list_blobs(name_starts_with=file_path)
+
+            for blob in blob_list:
+                if( self.__is_dir(file_path) ):
+                    self.delete_to_blob(container_name, blob.name)
+                else:
+                    remove_blob = self.blob_service_client.get_blob_client(container_name, file_path)
+                    if(remove_blob.exists()):
+                        remove_blob.delete_blob()
+        else:
+            remove_blob = self.blob_service_client.get_blob_client(container_name, file_path)
+            if(remove_blob.exists()):
+                remove_blob.delete_blob()
+
+            
+  
 
     def __cp_file_in_container(self, source_file_path, dest_file_path, name_container ):
 
@@ -151,14 +190,47 @@ class IOContainerData():
         remove_blob.delete_blob()
 
 
+    def write_dataframe_to_datalake(self, df, datalake_service_client, filesystem_name, dir_name, filename):
+    
+        file_path = f'{dir_name}/{filename}'
+
+        file_client = datalake_service_client.get_file_client(filesystem_name, file_path)
+
+        processed_df = df.to_parquet(index=False)
+
+        file_client.upload_data(data=processed_df,overwrite=True, length=len(processed_df))
+
+        file_client.flush_data(len(processed_df))
+
+
+
+    def download(self, df, path_file, name_container,  sep=','):
+
+        _path = f"abfs://{name_container}/{path_file}"
+
+        logging.info(f"Arquivo processado de download {_path}")
+
+        df.to_csv(
+            _path,
+            sep, 
+            storage_options={
+                "connection_string": self.connect_str
+            },
+            index=False)
+
+        logging.info(f"Arquivo processado de download {_path} finalizado")
+
     def load(self, path_file, name_container,  sep=',', header=0, dtype=None, chunksize=None) -> pd.DataFrame:
 
         self.get_extension(path_file)
+        _path = f"abfs://{name_container}/{path_file}"
+
+        logging.info(f"Arquivo do load do arquivo {_path}")
 
         if (self.extension == ".xlsx" ):
             
             self.pd =  pd.read_excel(
-                    f"abfs://{name_container}/{path_file}",
+                    _path,
                     storage_options={
                         "connection_string": self.connect_str
                     },
@@ -170,25 +242,24 @@ class IOContainerData():
         elif( self.extension == ".xls" ):
             
             self.pd =  pd.read_excel( 
-                    f"abfs://{name_container}/{path_file}",
+                    _path,
                     storage_options={
                         "connection_string": self.connect_str
                     },
                     header=header, 
                     dtype=dtype
                 )
-
         else:
-            
             self.pd =  pd.read_csv( 
-                    f"abfs://{name_container}/{path_file}",
+                    _path,
                     storage_options={
                         "connection_string": self.connect_str
                     },
                     header=header, 
                     sep=sep, 
                     dtype=dtype, 
-                    chunksize=chunksize
+                    chunksize=chunksize,
+                    low_memory=False
                 )
         
         return self.pd
@@ -197,17 +268,29 @@ class IOContainerData():
 
 if __name__ == '__main__':
 
-    transferContainer = IOContainerData()
+    file_path = "datalake/filesystem/saleforce/bdm/input/Oportunidades Em andamento BDMs.xlsx_1.csv"
 
-    transferContainer.get_content_length(transferContainer.name_container_silver, 
-    "datalake/database/db_cateira/sfa_cateira_completa_diaria/input/cliente_tudo.csv");
+    path = os.path.dirname(file_path)
+    name_file = Path(file_path).stem + ".parquet"
+    name = os.path.join(path, name_file)
+
+
+    print(name)
+
+    #transferContainer = IOContainerData()
+
+    ##transferContainer.delete_to_blob(transferContainer.name_container_silver,
+    #"datalake/database/db_cateira/sfa_cateira_completa_diaria/")
+
+    #transferContainer.get_content_length(transferContainer.name_container_silver, 
+    #"datalake/database/db_cateira/sfa_cateira_completa_diaria/input/cliente_tudo.csv");
 
     #f = transferContainer.get_file(transferContainer.name_container_silver, 
     #"datalake/database/db_cateira/sfa_cateira_completa_diaria/input/cliente_tudo.csv");
     #print(f)
 
-    d = { 'nome': ['nome_1', 'nome_2'], 'email': ['email_1', 'email_2']}
-    df = pd.DataFrame(data=d)
+    #d = { 'nome': ['nome_1', 'nome_2'], 'email': ['email_1', 'email_2']}
+    #df = pd.DataFrame(data=d)
     #output = df.to_csv (index_label="idx", encoding = "utf-8")
     #print(output)
 
